@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codecommit._jsii
@@ -20,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codecommit-backup",
-    "1.0.45",
+    "1.0.47",
     __name__[0:-6],
-    "cdk-codecommit-backup@1.0.45.jsii.tgz",
+    "cdk-codecommit-backup@1.0.47.jsii.tgz",
 )
 
 __all__ = [
